@@ -31,7 +31,7 @@ import ts.util.text.*;
  * {@link ts.util.file.FileOperation FileOperation}NX̋@\NXB
  *
  * @author  V.
- * @version $Revision: 1.2 $, $Date: 2007/05/27 16:13:10 $
+ * @version $Revision: 1.3 $, $Date: 2007/10/09 16:57:13 $
  */
 public class FileOperation02InnerTest extends FunctionTester
 {
@@ -1327,6 +1327,39 @@ public class FileOperation02InnerTest extends FunctionTester
     FALSE(dst.exists());
   }
 
+  public void copyInner_9()
+  {
+    MSG("Rs[̐efBNg݂ȂƂɃG[ƂȂꍇB");
+
+    ObjectInspector oi = new ObjectInspector(this);
+    FileOperation fop = new FileOperation();
+    Class[] types = { File.class, File.class };
+    Object[] values = new Object[2];
+
+    @SuppressWarnings("serial")
+    File src = new File(DIRS[3].getPath()) {
+      public boolean isDirectory() { return false; }
+      public boolean isFile() { return true; }
+    };
+    File dst =new File(WORKDIR, "aaa/bbb/ccc");
+    TRUE(DIRS[3].exists());
+    FALSE(dst.exists());
+
+    try {
+      values[0] = src;
+      values[1] = dst;
+      oi.invokeMethod(fop, "copyInner", types, values);
+      NG();
+    } catch (IOException e) {
+      OK(e);
+    } catch (Exception e) {
+      NG(e);
+    }
+
+    TRUE(DIRS[3].exists());
+    FALSE(dst.exists());
+  }
+
   public void moveInner_withFilter()
   {
     MSG("ʏ̃t@C̈ړB");
@@ -1434,7 +1467,7 @@ public class FileOperation02InnerTest extends FunctionTester
     Class[] types = { File.class, File.class, FileFilter.class };
     Object[] values = new Object[3];
 
-    TRUE(FILES[3].exists());
+    TRUE(DIRS[3].exists());
     TRUE(FILES[3].exists());
     TRUE(FILES[8].exists());
     TRUE(FILES[4].exists());
@@ -1926,4 +1959,39 @@ public class FileOperation02InnerTest extends FunctionTester
     TRUE(DIRS[3].exists());
     FALSE(dst.exists());
   }
+
+  public void copyInner_withFilter08()
+  {
+    MSG("Rs[̐efBNg݂ȂƂɃG[ƂȂꍇB");
+
+    ObjectInspector oi = new ObjectInspector(this);
+    FileOperation fop = new FileOperation();
+    Class[] types = { File.class, File.class, FileFilter.class };
+    Object[] values = new Object[3];
+
+    @SuppressWarnings("serial")
+    File src = new File(DIRS[3].getPath()) {
+      public boolean isDirectory() { return false; }
+      public boolean isFile() { return true; }
+    };
+    File dst =new File(WORKDIR, "aaa/bbb/ccc");
+    TRUE(DIRS[3].exists());
+    FALSE(dst.exists());
+
+    FileFilter filter = new FileTypeFilter(FileType.File);
+    try {
+      values[0] = src;
+      values[1] = dst;
+      values[2] = filter;
+      oi.invokeMethod(fop, "copyInner", types, values);
+      NG();
+    } catch (IOException e) {
+      OK(e);
+    } catch (Exception e) {
+      NG(e);
+    }
+
+    TRUE(DIRS[3].exists());
+    FALSE(dst.exists());
+  }
 }
