@@ -29,7 +29,7 @@ import java.util.*;
  * {@link ts.util.file.FileOperationy FileOperation}NX̋@\NXB
  *
  * @author  V.
- * @version $Revision: 1.2 $, $Date: 2007/05/27 16:13:11 $
+ * @version $Revision: 1.3 $, $Date: 2007/10/09 16:57:13 $
  */
 public class FileOperation05CopyTest extends FunctionTester
 {
@@ -424,6 +424,35 @@ public class FileOperation05CopyTest extends FunctionTester
     }
   }
 
+  public void copy_011()
+  {
+    MSG("Rs[̃t@C̐efBNg݂ȂƂɃG[ƂȂꍇB");
+
+    @SuppressWarnings("serial")
+    File src = new File(DIRS[4].getPath()) {
+      // copyFile ŗO𔭐
+      public boolean isDirectory() { return false; }
+    };
+    File dst = new File(WORKDIR, "aaa/bbb/ccc/ddd");
+
+    TRUE(src.exists());
+    FALSE(dst.exists());
+
+    try {
+      FileOperation.copy(src, dst);
+      NG();
+    }
+    catch (IOException e) {
+      OK(e);
+    }
+    catch (Exception e) {
+      NG(e);
+    }
+
+    TRUE(src.exists());
+    FALSE(dst.exists());
+  }
+
   public void copy_withFilter()
   {
     MSG("ʏ̃t@C𓯂fBNgɕʖŃRs[ꍇB");
@@ -804,6 +833,38 @@ public class FileOperation05CopyTest extends FunctionTester
     }
   }
 
+  public void copy_withFilter011()
+  {
+    MSG("Rs[̃t@C̐efBNg݂ȂƂɃG[ƂȂꍇB");
+
+    FileFilter filter = new FileTypeFilter(FileType.File);
+
+    @SuppressWarnings("serial")
+    File src = new File(DIRS[4].getPath()) {
+      // copyFile ŗO𔭐
+      public boolean isDirectory() { return false; }
+      public boolean isFile() { return true; }
+    };
+    File dst = new File(WORKDIR, "aaa/bbb/ccc/ddd");
+
+    TRUE(src.exists());
+    FALSE(dst.exists());
+
+    try {
+      FileOperation.copy(src, dst, filter);
+      NG();
+    }
+    catch (IOException e) {
+      OK(e);
+    }
+    catch (Exception e) {
+      NG(e);
+    }
+
+    TRUE(src.exists());
+    FALSE(dst.exists());
+  }
+
   public void copyRecursive()
   {
     MSG("łȂfBNgRs[ꍇB");
