@@ -29,7 +29,7 @@ import java.util.*;
  * <code>AbstractResource</code>NX̋@\NXB
  *
  * @author  V. 
- * @version $Revision: 1.2 $, $Date: 2007/02/15 15:28:04 $
+ * @version $Revision: 1.3 $, $Date: 2007/05/27 16:13:13 $
  */
 public class AbstractResourceTest extends FunctionTester
 {
@@ -67,6 +67,7 @@ public class AbstractResourceTest extends FunctionTester
 
   /* -- test case -- */
 
+  @Deprecated
   public void constructor()
   {
     MSG("ftHgRXgN^̊mFB");
@@ -78,9 +79,23 @@ public class AbstractResourceTest extends FunctionTester
     EQUAL(res.getAttributeSeparator(), ',');
     EQUAL(res.getAttributeMatchMark(), '=');
     EQUAL(res.getPath(), null);
+  }
+
+  public void constructor_str()
+  {
+    MSG("ftHgRXgN^̊mFB");
+
+    AbstractResource res = new ResourceEx();
+    EQUAL(res.elementSeparator(), ".");
+    EQUAL(res.attributeParenthesis()[0], "(");
+    EQUAL(res.attributeParenthesis()[1], ")");
+    EQUAL(res.attributeSeparator(), ",");
+    EQUAL(res.attributeMatchMark(), "=");
+    EQUAL(res.getPath(), null);
     NOTNULL(res);
   }
 
+  @Deprecated
   public void setElementSeparator()
   {
     MSG("L[vfZp[^ݒ肷郁\bh̊mFB");
@@ -92,6 +107,42 @@ public class AbstractResourceTest extends FunctionTester
     EQUAL(res.getElementSeparator(), '/');
   }
 
+  public void setElementSeparator_str()
+  {
+    MSG("L[vfZp[^ݒ肷郁\bh̊mFB");
+
+    AbstractResource res = new ResourceEx();
+    EQUAL(res.elementSeparator(), ".");
+
+    res.setElementSeparator("/");
+    EQUAL(res.elementSeparator(), "/");
+
+    res.setElementSeparator("\uD800\uDC33");
+    EQUAL(res.elementSeparator(), "\uD800\uDC33");
+
+    try {
+      res.setElementSeparator(null);
+      NG();
+    } catch (AssertionError e) {
+      OK(e);
+    }
+
+    try {
+      res.setElementSeparator("");
+      NG();
+    } catch (IllegalArgumentException e) {
+      OK(e);
+    }
+
+    try {
+      res.setElementSeparator("//");
+      NG();
+    } catch (IllegalArgumentException e) {
+      OK(e);
+    }
+  }
+
+  @Deprecated
   public void setAttributeParenthesis()
   {
     MSG("L[͂ފʂݒ肷郁\bh̊mFB");
@@ -105,6 +156,61 @@ public class AbstractResourceTest extends FunctionTester
     EQUAL(res.getAttributeParenthesis()[1], ']');
   }
 
+  public void setAttributeParenthesis_str()
+  {
+    MSG("L[͂ފʂݒ肷郁\bh̊mFB");
+
+    AbstractResource res = new ResourceEx();
+    EQUAL(res.attributeParenthesis()[0], "(");
+    EQUAL(res.attributeParenthesis()[1], ")");
+
+    res.setAttributeParenthesis("[", "]");
+    EQUAL(res.attributeParenthesis()[0], "[");
+    EQUAL(res.attributeParenthesis()[1], "]");
+
+    res.setAttributeParenthesis("\uD800\uDC32", "\uD800\uDC33");
+    EQUAL(res.attributeParenthesis()[0], "\uD800\uDC32");
+    EQUAL(res.attributeParenthesis()[1], "\uD800\uDC33");
+
+    try {
+      res.setAttributeParenthesis(null, ")");
+      NG();
+    } catch (AssertionError e) {
+      OK(e);
+    }
+    try {
+      res.setAttributeParenthesis("(", null);
+      NG();
+    } catch (AssertionError e) {
+      OK(e);
+    }
+    try {
+      res.setAttributeParenthesis("", ")");
+      NG();
+    } catch (IllegalArgumentException e) {
+      OK(e);
+    }
+    try {
+      res.setAttributeParenthesis("(", "");
+      NG();
+    } catch (IllegalArgumentException e) {
+      OK(e);
+    }
+    try {
+      res.setAttributeParenthesis("((", ")");
+      NG();
+    } catch (IllegalArgumentException e) {
+      OK(e);
+    }
+    try {
+      res.setAttributeParenthesis("(", "))");
+      NG();
+    } catch (IllegalArgumentException e) {
+      OK(e);
+    }
+  }
+
+  @Deprecated
   public void setAttributeSeparator()
   {
     MSG("L[̃Zp[^ݒ肷郁\bh̊mFB");
@@ -116,6 +222,40 @@ public class AbstractResourceTest extends FunctionTester
     EQUAL(res.getAttributeSeparator(), '|');
   }
 
+  public void setAttributeSeparator_str()
+  {
+    MSG("L[̃Zp[^ݒ肷郁\bh̊mFB");
+
+    AbstractResource res = new ResourceEx();
+    EQUAL(res.attributeSeparator(), ",");
+
+    res.setAttributeSeparator("|");
+    EQUAL(res.attributeSeparator(), "|");
+
+    res.setAttributeSeparator("\uD800\uDC32");
+    EQUAL(res.attributeSeparator(), "\uD800\uDC32");
+
+    try {
+      res.setAttributeSeparator(null);
+      NG();
+    } catch (AssertionError e) {
+      OK(e);
+    }
+    try {
+      res.setAttributeSeparator("");
+      NG();
+    } catch (IllegalArgumentException e) {
+      OK(e);
+    }
+    try {
+      res.setAttributeSeparator("||");
+      NG();
+    } catch (IllegalArgumentException e) {
+      OK(e);
+    }
+  }
+
+  @Deprecated
   public void setAttributeMatchMark()
   {
     MSG("L[̖Oƒl̑Ή}[Nݒ肷郁\bh̊mFB");
@@ -127,6 +267,38 @@ public class AbstractResourceTest extends FunctionTester
     EQUAL(res.getAttributeMatchMark(), ':');
   }
 
+  public void setAttributeMatchMark_str()
+  {
+    MSG("L[̖Oƒl̑Ή}[Nݒ肷郁\bh̊mFB");
+
+    AbstractResource res = new ResourceEx();
+    EQUAL(res.attributeMatchMark(), "=");
+
+    res.setAttributeMatchMark(":");
+    EQUAL(res.attributeMatchMark(), ":");
+
+    try {
+      res.setAttributeMatchMark(null);
+      NG();
+    } catch (AssertionError e) {
+      OK(e);
+    }
+
+    try {
+      res.setAttributeMatchMark("");
+      NG();
+    } catch (IllegalArgumentException e) {
+      OK(e);
+    }
+
+    try {
+      res.setAttributeMatchMark(":=");
+      NG();
+    } catch (IllegalArgumentException e) {
+      OK(e);
+    }
+  }
+
   public void splitKey()
   {
     MSG("L[vfɕ郁\bh̊mFB");
@@ -150,6 +322,21 @@ public class AbstractResourceTest extends FunctionTester
       NG(e);
     }
 
+    try {
+      List<String> lst3 = res.splitKey("aaa(bbb=ccc)");
+      EQUAL(lst3.size(), 1);
+      EQUAL(lst3.get(0), "aaa(bbb=ccc)");
+    } catch (Exception e) {
+      NG(e);
+    }
+    try {
+      List<String> lst3 = res.splitKey("aaa(bbb=ccc,ddd=eee,fff=ggg)");
+      EQUAL(lst3.size(), 1);
+      EQUAL(lst3.get(0), "aaa(bbb=ccc,ddd=eee,fff=ggg)");
+    } catch (Exception e) {
+      NG(e);
+    }
+
     try {
       List<String> lst3 = res.splitKey("aaa.bbb(Y=2).ccc");
       EQUAL(lst3.size(), 3);
@@ -609,6 +796,7 @@ public class AbstractResourceTest extends FunctionTester
     EQUAL(lst4.get(1)[1], "");
   }
 
+  @Deprecated
   public void copy_constructor()
   {
     MSG("Rs[RXgN^̊mFB");
@@ -663,7 +851,7 @@ public class AbstractResourceTest extends FunctionTester
       NG(e);
     }
 
-    final StringBuffer buf = new StringBuffer();
+    final StringBuilder buf = new StringBuilder();
 
     ResourceEx res = new ResourceEx() {
       @Override
@@ -713,7 +901,7 @@ public class AbstractResourceTest extends FunctionTester
       NG(e);
     }
 
-    final StringBuffer buf = new StringBuffer();
+    final StringBuilder buf = new StringBuilder();
     ResourceEx res2 = new ResourceEx() {
       @Override
       protected void load(InputStream in) throws java.io.IOException {
